@@ -1,24 +1,12 @@
 from flask import send_file
 
+from mark_excel.normal_write import Write
 
-class Write(object):
+
+class NormalWrite(Write):
     def __init__(self, mark_excel):
         self.mark_excel = mark_excel
 
-    def save_flask_response(self, local_path, file_name=None):
-        """
-        文件存储，同时返回Flask的接口Response对象
-        :param local_path: 文件保存路径
-        :param file_name: 文件名字，如果不传就按照local_path来解析
-        :return:
-        """
-        if file_name is None:
-            file_name = local_path.split("/")[-1]
-        self.save(local_path)
-        return send_file(local_path, attachment_filename=file_name,
-                         as_attachment=True,
-                         mimetype='application/vnd.openxmlformats-officedocument.spreadsheetml.sheet')
-
     def save(self, local_path):
         """
         保存EXCEL文件
@@ -27,7 +15,7 @@ class Write(object):
         """
         self.mark_excel.workbook.save(local_path)
 
-    def create_sheet(self, title: str, index: int):
+    def create_sheet(self, title: str, index: int = 0):
         """
         新建一个sheet
         :param title: sheet标题
@@ -42,7 +30,7 @@ class Write(object):
         :param row_index:要写入第几行，从1开始计数
         :param value:写入的值
         :param length:合并单元格数量
-
+        :param sheet:要操作的sheet,默认第一个sheet
         :return:
         """
         if sheet is None:
@@ -72,3 +60,18 @@ class Write(object):
             sheet.column_dimensions[self.mark_excel.LINE[i]].width = self.mark_excel.width
             # 设置该列的对齐方式
             sheet['{}{}'.format(self.mark_excel.LINE[i], row_index)].alignment = self.mark_excel.align
+
+    def merge(self, start_line, end_line, start_col, end_col, value, sheet=None):
+        """
+        合并行或者列
+        :param start_line: 合并开始行
+        :param end_line: 合并开始行
+        :param start_col: 合并开始行
+        :param end_col: 合并开始行
+        :param value: 单元格值
+        :param sheet: 要操作的sheet,默认第一个sheet
+        :return:
+        """
+        if sheet is None:
+            sheet = self.mark_excel.workbook.worksheets[0]
+        sheet.merge_cells(value, start_line, start_col, end_line, end_col)
